@@ -1,9 +1,11 @@
 """Full statistics protocol."""
 
 from __future__ import annotations
-from typing import IO, Iterator, NamedTuple
+from typing import IO, Iterator, List, NamedTuple
 
+from mcipc.functions import json_serializable
 from mcipc.query.proto.common import MAGIC
+from mcipc.query.proto.common import NULL
 from mcipc.query.proto.common import ip_or_hostname
 from mcipc.query.proto.common import random_session_id
 from mcipc.query.proto.common import BigEndianSignedInt32
@@ -15,7 +17,6 @@ __all__ = ['Request', 'FullStats']
 
 
 PADDING = b'\x00\x00\x00\x00'
-NULL = b'\0'
 
 
 def read_stats(file: IO) -> dict:
@@ -116,6 +117,8 @@ class Request(NamedTuple):
         return cls(session_id=random_session_id(),
                    challenge_token=challenge_token)
 
+
+@json_serializable
 class FullStats(NamedTuple):
     """Full statistics response."""
 
@@ -131,33 +134,15 @@ class FullStats(NamedTuple):
     max_players: int
     host_port: int
     host_ip: IPAddressOrHostname
-    players: tuple
+    players: List[str]
 
     @classmethod
     def read(cls, file: IO) -> FullStats:
         """Read a full stats response."""
         type_ = Type.read(file)
         session_id = BigEndianSignedInt32.read(file)
-        _ = file.read(11)   # Discard padding.
+        file.read(11)   # Discard padding.
         stats = read_stats(file)
-        _ = file.read(10)     # Discard padding.
-        players = tuple(read_players(file))
+        file.read(10)   # Discard padding.
+        players = list(read_players(file))
         return cls(type_, session_id, *stats_from_dict(stats), players)
-
-    def to_json(self) -> dict:
-        """Returns a JSON-ish dict."""
-        return {
-            'type': self.type.value,
-            'session_id': self.session_id,
-            'host_name': self.host_name,
-            'game_type': self.game_type,
-            'game_id': self.game_id,
-            'version': self.version,
-            'plugins': self.plugins,
-            'map': self.map,
-            'num_players': self.num_players,
-            'max_players': self.max_players,
-            'host_port': self.host_port,
-            'host_ip': str(self.host_ip),
-            'players': self.players
-        }
