@@ -1,7 +1,8 @@
 """Implementation of the fill command."""
 
 from mcipc.rcon.client import Client
-from mcipc.rcon.types import FillMode, Vec3
+from mcipc.rcon.enumerations import FillMode
+from mcipc.rcon.types import FillMode as FillModeHint, Vec3
 
 
 __all__ = ['fill']
@@ -9,7 +10,7 @@ __all__ = ['fill']
 
 # pylint: disable=C0103,R0913,W0622
 def fill(self: Client, from_: Vec3, to: Vec3, block: str,
-         mode: FillMode = None, filter: str = None) -> str:
+         mode: FillModeHint = None, filter: str = None) -> str:
     """Fills all or parts of a region with a specific block."""
 
     command = ['fill', from_, to, block]
