@@ -3,6 +3,7 @@
 from re import fullmatch
 from typing import NamedTuple
 
+from mcipc.functions import json_serializable
 from mcipc.rcon.errors import NoPlayerFound
 
 
@@ -12,16 +13,13 @@ __all__ = ['KickedPlayer', 'parse']
 REGEX = 'Kicked (.*): (.*)'
 
 
+@json_serializable
 class KickedPlayer(NamedTuple):
     """Stores information about a kicked player."""
 
     name: str
     reason: str
 
-    def to_json(self) -> dict:
-        """Returns a JSON-ish dict."""
-        return {'name': self.name, 'reason': self.reason}
-
 
 def parse(text: str) -> KickedPlayer:
     """Parses a kicked player from the text."""
