@@ -1,9 +1,11 @@
 """Information about online players."""
 
 from re import Match, fullmatch
-from typing import Iterator, NamedTuple, Tuple
+from typing import Iterator, List, NamedTuple, Optional
 from uuid import UUID
 
+from mcipc.functions import json_serializable
+
 
 __all__ = ['Player', 'Players', 'parse']
 
@@ -14,37 +16,29 @@ REGEX_PAPER = '.+ §c(\\d+)§6 .+ §c(\\d+)§6 .+\\.([\\s\\S]*)'
 REGEX_PAPER_NAME = '§6(.+)§r: (?:§4)?(\\w+)(?:§r)?§f'
 
 
+@json_serializable
 class Player(NamedTuple):
     """Player names with optional UUIDs."""
 
     name: str
-    uuid: UUID = None
-    state: str = None
-
-    def to_json(self) -> dict:
-        """Returns a JSON-ish dict."""
-        return {'name': str(self), 'uuid': self.uuid.hex, 'state': self.state}
+    uuid: Optional[UUID] = None
+    state: Optional[str] = None
 
 
+@json_serializable
 class Players(NamedTuple):
     """Online players information."""
 
     online: int
     max: int
-    players: Tuple[Player]
+    players: List[Player]
 
     @property
-    def names(self) -> Tuple[str]:  # XXX: For backward compatibility.
-        """Returns a tuple of the players' names."""
-        return tuple(player.name for player in self.players)
-
-    def to_json(self) -> dict:
-        """Returns a JSON-ish dict."""
-        return {
-            'online': self.online,
-            'max': self.max,
-            'players': [player.to_json() for player in self.players]
-        }
+    def names(self) -> List[str]:
+        """Returns a list of the players' names
+        for backward compatibility.
+        """
+        return [player.name for player in self.players]
 
 
 def player_from_java_name(name: str) -> Player:
@@ -54,8 +48,7 @@ def player_from_java_name(name: str) -> Player:
         raise ValueError(f'Invalid Java Edition server string: {name}')
 
     name, uuid = match.groups()
-    uuid = None if uuid is None else UUID(uuid)
-    return Player(name, uuid=uuid)
+    return Player(name, uuid=None if uuid is None else UUID(uuid))
 
 
 def players_from_java_names(names: str) -> Iterator[Player]:
@@ -87,7 +80,7 @@ def from_java(match: Match) -> Players:
 
     online, max_, names = match.groups()
     players = players_from_java_names(names)
-    return Players(int(online), int(max_), tuple(players))
+    return Players(int(online), int(max_), list(players))
 
 
 def from_paper(match: Match) -> Players:
@@ -97,7 +90,7 @@ def from_paper(match: Match) -> Players:
 
     online, max_, names = match.groups()
     players = players_from_paper_names(names)
-    return Players(int(online), int(max_), tuple(players))
+    return Players(int(online), int(max_), list(players))
 
 
 def parse(text: str) -> Players:
